@@ -1,7 +1,7 @@
 package PICA::Writer::Base;
 use v5.14.1;
 
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 use Scalar::Util qw(blessed openhandle reftype);
 use PICA::Schema qw(clean_pica);
@@ -77,21 +77,28 @@ sub write_record {
 sub write_field {
     my ($self, $field) = @_;
 
-    my $fh = $self->{fh};
+    $self->write_start_field($field);
 
-    $self->write_annotation($field);
-    $self->write_identifier($field);
-    $fh->print(' ');
     for (my $i = 3; $i < scalar @$field; $i += 2) {
         $self->write_subfield($field->[$i - 1], $field->[$i]);
     }
 
-    $fh->print($self->END_OF_FIELD);
+    $self->{fh}->print($self->END_OF_FIELD);
 }
 
-sub write_annotation {
+sub annotation {
+    my ($self, $field) = @_;
 
-    # ignore field annotation by default
+    return unless $self->{annotate} // @$field % 2;
+    return @$field % 2 ? $field->[$#$field] : " ";
+}
+
+sub write_start_field {
+    my ($self, $field) = @_;
+
+    # ignore annotation by default
+    $self->write_identifier($field);
+    $self->{fh}->print(' ');
 }
 
 sub write_subfield {
@@ -190,9 +197,9 @@ L<PICA::Writer::Plus> using color names from L<Term::ANSIColor>, e.g.
 
 =head2 annotate
 
-Writer L<PICA::Writer::Plain> includes optional field annotations. Set this
-option to true to enforce field annotations (set to an empty space if missing)
-or to false to ignore them.
+Writer L<PICA::Writer::Plain> and L<PICA::Writer::Plus> includes optional field
+annotations. Set this option to true to enforce field annotations (set to an
+empty space if missing) or to false to ignore them.
 
 =head1 SEE ALSO
 
